<?php
/**
 * levii functions and definitions
 *
 * @package Levii
 */
define( 'LEVII_THEME_VERSION' , '1.1.3' );

// Upgrade / Order Premium page
require get_template_directory() . '/upgrade/upgrade.php';

// Load WP included scripts
require get_template_directory() . '/inc/template-tags.php';
require get_template_directory() . '/inc/extras.php';
require get_template_directory() . '/inc/jetpack.php';
require get_template_directory() . '/inc/customizer.php';

// Load Customizer Library scripts
require get_template_directory() . '/customizer/customizer-options.php';
require get_template_directory() . '/customizer/customizer-library/customizer-library.php';
require get_template_directory() . '/customizer/styles.php';
require get_template_directory() . '/customizer/mods.php';

// Load TGM plugin class
require_once get_template_directory() . '/inc/class-tgm-plugin-activation.php';
// Add customizer Upgrade class
require_once( get_template_directory() . '/includes/levii-pro/class-customize.php' );

if ( ! function_exists( 'levii_theme_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function levii_theme_setup() {
    
    /**
     * Set the content width based on the theme's design and stylesheet.
     */
    global $content_width;
    if ( ! isset( $content_width ) ) {
        $content_width = 718; /* pixels */
    }

	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on levii, use a find and replace
	 * to change 'levii' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'levii', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );
    
    add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
	 */
    add_theme_support('post-thumbnails');
    
    add_image_size('levii_blog_img_side', 400, 480, true );
    add_image_size('levii_blog_img_top', 720, 260, true );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'levii' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form', 'comment-form', 'comment-list', 'gallery', 'caption',
	) );

	/*
	 * Enable support for Post Formats.
	 * See http://codex.wordpress.org/Post_Formats
	 */
	add_theme_support( 'post-formats', array(
		'aside', 'image', 'video', 'quote', 'link',
	) );
    
    // The custom header is used for top header image
    add_theme_support('custom-header', array(
        'default-image' => '',
        'width'         => 1000,
        'height'        => 360,
        'flex-width' => false,
        'flex-height' => true,
        'header-text' => false,
    ));
    
	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'levii_custom_background_args', array(
		'default-color' => 'F0F0F0',
		'default-image' => '',
	) ) );
    
    add_theme_support( 'woocommerce' );
}
endif; // levii_theme_setup
add_action( 'after_setup_theme', 'levii_theme_setup' );

/**
 * Register widget area.
 *
 * @link http://codex.wordpress.org/Function_Reference/register_sidebar
 */
function levii_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Sidebar', 'levii' ),
		'id'            => 'sidebar-1',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h4 class="widget-title">',
		'after_title'   => '</h4>',
	) );
}
add_action( 'widgets_init', 'levii_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function levii_theme_scripts() {
    wp_enqueue_style( 'levii-google-body-font-default', '//fonts.googleapis.com/css?family=Open+Sans:400,300,300italic,400italic,600,600italic,700,700italic', array(), LEVII_THEME_VERSION );
    wp_enqueue_style( 'levii-google-heading-font-default', '//fonts.googleapis.com/css?family=Roboto:400,300,300italic,400italic,500,500italic,700,700italic', array(), LEVII_THEME_VERSION );
    
    wp_enqueue_style( 'levii-fontawesome', get_template_directory_uri().'/includes/font-awesome/css/font-awesome.css', array(), '4.7.0' );
	wp_enqueue_style( 'levii-style', get_stylesheet_uri(), array(), LEVII_THEME_VERSION );

    wp_enqueue_script( 'levii-caroufredSel', get_template_directory_uri() . '/js/jquery.carouFredSel-6.2.1-packed.js', array('jquery'), LEVII_THEME_VERSION, true );
    
    wp_enqueue_script( 'levii-customjs', get_template_directory_uri() . '/js/custom.js', array('jquery'), LEVII_THEME_VERSION, true );

	wp_enqueue_script( 'levii-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), LEVII_THEME_VERSION, true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'levii_theme_scripts' );

/**
 * Enqueue Levii custom customizer styling.
 */
function levii_load_customizer_style() {
    wp_enqueue_style( 'levii-customizer-css', get_template_directory_uri() . '/customizer/customizer-library/css/customizer.css' );
}    
add_action( 'customize_controls_enqueue_scripts', 'levii_load_customizer_style' );

/**
 * Adjust is_home query if kra-blog-cats is set
 */
function levii_set_blog_queries( $query ) {
    $blog_query_set = '';
    if ( get_theme_mod( 'kra-blog-cats', false ) ) {
        $blog_query_set = get_theme_mod( 'kra-blog-cats' );
    }
    
    if ( $blog_query_set ) {
        // do not alter the query on wp-admin pages and only alter it if it's the main query
        if ( !is_admin() && $query->is_main_query() ){
            if ( is_home() ){
                $query->set( 'cat', $blog_query_set );
            }
        }
    }
}
add_action( 'pre_get_posts', 'levii_set_blog_queries' );

/**
 * Display recommended plugins with the TGM class
 */
function levii_register_required_plugins() {
    $plugins = array(
        // The recommended WordPress.org plugins.
        array(
            'name'      => __( 'Page Builder', 'levii' ),
            'slug'      => 'siteorigin-panels',
            'required'  => false,
        ),
        array(
            'name'      => __( 'WooCommerce', 'levii' ),
            'slug'      => 'woocommerce',
            'required'  => false,
        ),
        array(
            'name'      => __( 'Widgets Bundle', 'levii' ),
            'slug'      => 'siteorigin-panels',
            'required'  => false,
        ),
        array(
            'name'      => __( 'Contact Form 7', 'levii' ),
            'slug'      => 'contact-form-7',
            'required'  => false,
        ),
        array(
            'name'      => __( 'Breadcrumb NavXT', 'levii' ),
            'slug'      => 'breadcrumb-navxt',
            'required'  => false,
        ),
        array(
            'name'      => __( 'Meta Slider', 'levii' ),
            'slug'      => 'ml-slider',
            'required'  => false,
        )
    );
    $config = array(
        'id'           => 'levii',
        'menu'         => 'tgmpa-install-plugins',
        'message'      => '',
    );

    tgmpa( $plugins, $config );
}
add_action( 'tgmpa_register', 'levii_register_required_plugins' );
